@@ -1362,7 +1362,7 @@ __END__
 
 =head1 NAME
 
-Sim::OPT::report.
+Sim::OPT::Report.
 
 =head1 SYNOPSIS
 
@@ -1371,11 +1371,11 @@ Sim::OPT::report.
 
 =head1 DESCRIPTION
 
-Sim::OPT::Report is the module used by Sim::OPT to retrieve simulation results. Sim::OPT::Report performs two kinds of action. The first, which is required only by certain simulation programs, is that of making the simulation program write the results in a user-specified text format. This functionality is platform-specific and is presently implemented only for ESP-r (EnergyPlus does not require that). The second functionality is that of gathering the results in a user-specified manner. That functionality is based on pattern-matching and is not platform-specific.
+Sim::OPT::Report is the module used by Sim::OPT to retrieve simulation results. Sim::OPT::Report performs two kinds of action. The first, which is required only by certain simulation programs, is that of making the simulation program write the results in a user-specified text format. This functionality is platform-specific and is presently implemented only for ESP-r (EnergyPlus does not require that). The second functionality is that of gathering the results in a user-specified manner. That functionality is based on pattern-matching and is not simulation-program-specific.
 
 =head2 EXPORT
 
-"opt".
+"retrieve" "report".
 
 =head1 SEE ALSO
 
